import sys
import scipy as sp
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import scipy.signal
import glob
from scipy.optimize import curve_fit
import math
from matplotlib.ticker import FormatStrFormatter
import matplotlib.dates as mdates


from Functions_Sonic import *
sys.path.append("../../../general")
from Functions_general import *


#%% Functions specific for this file

def zb(p, p_GND, T_GND):

    '''
    according ICAO but with flexible ground pressure and temperature
    To estimate the ground parameters:      
    p_GND = df.pp.max() ## simply the maximum pressure of the entire record! 
    T_GND = df.TT[df.pp >= (df.pp.max() - 0.5)].median() ## taking an height interval from GND (maximum pressure) and about 4 m higher (-0.5 hPa) and then calculating the median value of the temperature readings in that interval.       
    These ground values are estimated from the entire record, but the difference for start and end of a balloon launch is less 5 m.        
    The reference for leg4 is always the standard meteorology! Maybe it makes sense to store the ground values in a table!
    T_GND in deg C
    p and p_GND in same unit
    '''     
    p = p * 1.
    p_GND = p_GND * 1.
    T_GND = T_GND * 1.
    RL = 287. # J / kg / K
    g = 9.80665 # m/s2
    return RL * (T_GND + 273.15) / g * np.log(p_GND / p )  






#%% Definitions
    
# Define sampling frequencies in Hz
fs_Balloon = 50.0


#for day in ['2020-07-10', '2020-07-13', '2020-07-14', '2020-07-15', '2020-07-21', '2020-07-23', '2020-07-24', '2020-07-26' ]:
for day in [ '2020-07-13', '2020-07-14', '2020-07-15', '2020-07-21', '2020-07-23', '2020-07-24', '2020-07-26' ]:
#for day in ['2020-07-10']:
    

    #%% Define data to analyze  
    
    # Sonic Anemometer data
    path = '../Data/Data_postprocessed/lev0/'
    filenames = glob.glob(path +"*"+ day[:10] + "*.dat")
    
    print '----------------'
    print day
    print '----------------'
    
    #choose only one file per day
    filenames = filenames
    filenames = (filenames,) if not isinstance(filenames, (tuple, list)) else filenames    
    
    # iterate over all flights at a day
    for datafile in filenames:
        
        # Dayly data
        maxh, cloud_top, cloud_base, t1, t2, t3, p0, T0 = sonic_dayly_data(datafile)
    
        #%%  Read data data
        
        ## Read balloon data
        Balloon = read_postprocessed(datafile)
        
        ## Read radiosonde data
        if day == '2020-07-15':
            RStime = '17'
        else:
            RStime = '11'
        RS = read_radiosonde(folder = '../../Radiosondes/radiosondes/', date = day, time = RStime)
        RS = read_radiosonde_PANGAEA(folder = '../../Maturilli_2021_MOSAiC_radiosondes/datasets/', date = day, time = RStime)
        
        
        #%% Process data
        
        ### reindex to GPS time   
        Balloon.index = Balloon.GPStime  
        Balloon['time'] = (Balloon.index - Balloon.index[0]) / np.timedelta64(1,'s')

        #### cut data
          
        # remove data where IMU is not working yet
        if Balloon.LON.dropna().empty==True:
            start_time = Balloon.h_WGS84.first_valid_index() + pd.to_timedelta(60,'S')
        else: 
            start_time = Balloon.LON.first_valid_index()
        Balloon = Balloon[Balloon.index > start_time]

        # remove data where USA or IMU is not working any more
        Balloon = Balloon[Balloon.index < Balloon.T_PT100.last_valid_index()]
        Balloon = Balloon[Balloon.index < Balloon.h_WGS84.last_valid_index()]
        
        # cut where Sonic is lying in box (roll >1 or <-1)
        Balloon = Balloon[Balloon.roll > -0.4]
        Balloon = Balloon[Balloon.roll <  0.4]
        
        # cut data to begin after initial 360 degree rotation and end of flight
        if day == '2020-07-26': 
            Balloon = Balloon['{} 11:58:29.00'.format(day[:10]):]
        elif day == '2020-07-23': 
            Balloon = Balloon['{} 11:08:21.00'.format(day[:10]):'{} 12:36:15.00'.format(day[:10])]
        elif day == '2020-07-21': 
            Balloon = Balloon['{} 11:35:12.00'.format(day[:10]):'{} 13:04:59.00'.format(day[:10])]
        elif day == '2020-07-15': 
            Balloon = Balloon['{} 11:45:08.00'.format(day[:10]):'{} 14:43:55.00'.format(day[:10])]
        elif day == '2020-07-14': 
            Balloon = Balloon['{} 13:20:25.00'.format(day[:10]):]
        elif day == '2020-07-13': 
            Balloon = Balloon['{} 11:53:29.00'.format(day[:10]):'{} 15:20:38.00'.format(day[:10])]
            Balloon['{} 13:27:10.00'.format(day[:10]) : '{} 13:33:06.00'.format(day[:10])] = np.nan
        elif day == '2020-07-10': 
            Balloon = Balloon['{} 12:06:07.00'.format(day[:10]):]
 
        #plt.figure()
        #plt.suptitle(day)
        #plt.plot(Balloon.h_pres/100)
        #plt.plot(Balloon.LAT/100)
        #plt.plot(Balloon.roll) 
        #plt.plot(Balloon.yaw,'.')    
        #plt.plot(Balloon.T_PT100)
        #plt.legend()
        #plt.grid()          
        
        
        ### re-calculate motion correction and horizontal wind        ---->  defined for MOSAiC:  deltap = np.radians(-2.5)  deltaroll = np.radians(2.1)
        
        Balloon['w_E_lev_0'] = Balloon.w_E
        Balloon = correct_motion_lev1(Balloon, deltap=-2.5, deltar=2.1)
        Balloon = calculate_horizontal_wind(Balloon)
        Balloon['uv_E'] = (Balloon.u_E**2 + Balloon.v_E**2)**0.5 # re-clculate with new values


        # plot spectra for const-alt periods in turbulent environment
        if day == '2020-07-10': # strong yaw oscillations: motion correction ok for w, in u and v peak is still visible, this time segment shows improvement by installation angel offset
            data_spectrum = Balloon['{} 12:08:17.00'.format(day[:10]):'{} 12:11:19.00'.format(day[:10])]
        elif day == '2020-07-14': # motion correction works perfectly
            data_spectrum = Balloon['{} 14:28:55.00'.format(day[:10]):'{} 14:34:16.00'.format(day[:10])]
            data_spectrum = Balloon['{} 14:22:37.00'.format(day[:10]):'{} 14:27:47.00'.format(day[:10])]
        elif day == '2020-07-15': # not so good (not really in turbulence region)
            data_spectrum = Balloon['{} 14:26:26.00'.format(day[:10]):'{} 14:30:54.00'.format(day[:10])]
        else:
            data_spectrum = Balloon.iloc[:5000]
        #spectrum(data_spectrum,fs_Balloon,['w_USA', 'w_E', 'w_E_lev_0'], time_series=1 )
        #spectrum(data_spectrum,fs_Balloon,['u_E', 'v_E', 'w_E'], time_series=0 )
        #spectrum(data_spectrum,fs_Balloon,['u_USA', 'v_USA', 'w_USA'], time_series=1 )
        
            
        #### data corrections for all days:
      
        ## filter outliers
        for channel in ['h_pres', 'h_WGS84', 'Tv', 'T_PT100', 'RH_LinP', 'T_Thermo', 'u_E', 'v_E', u'w_E', 'horizontalwind', 'crosswind']:
            Balloon[channel] = Balloon[channel].where( np.abs(Balloon[channel] - Balloon[channel].rolling(int(fs_Balloon), center=True, min_periods=0).mean() ) <= (5* Balloon[channel].rolling(int(fs_Balloon), center=True, min_periods=0).std() ) , np.nan)
        
        ## Interpolate single NaNs
        Balloon = Balloon.interpolate(limit=1)
        
        ## drop not-needed columns
        Balloon.drop([ 'GPStime','n_c', 'w_E_lev_0'], axis=1, inplace=True)        
        Balloon.drop(['Tc', 'Td'], axis=1, inplace=True)   # Hygrometer was not working during MOSAiC

        ## rename columns 
        Balloon = Balloon.rename(columns={
                'LON': 'Lon',
                'LAT': 'Lat',
                'RH_LinP': 'RH',
                'crosswind': 'lateralwind',
                'horizontalwind': 'longitudinalwind'
                })
    
    
        ## Calculate barometric pressure
        
        #Balloon['p'] = h_to_p(Balloon.h_pres, p0=p0, T0=T0)
        Balloon['p'] = 1018.7 * np.exp( np.log(1-Balloon.h_pres/44330) *5.256 ) # formula is IMU-internal - personal communication with IMAR
        
        ## Ground pressure change throughout day
        
        p = Balloon.p # do not correct for MOSAiC data because height difference between start and landing is always below 5m
        
        
        ## re-calculate barometric height
        
        # ground values
        p0 = p.max()
        T0 = Balloon.T_PT100[ p >= (p.max() - 0.5)].median()
        
        #h = p_to_h(   p = p*100 , p0 = P0, T0 = T0, h0 = 1.5) 
        h = zb(p = p, p_GND = p0, T_GND = T0)
        
        ## correct GPS height
        Balloon.h_WGS84 = Balloon.h_WGS84 - np.nanmedian(Balloon.h_WGS84 - h) # (difference to barometric altitude)
        
        # plot
#        fig=plt.figure(figsize = (15,9))
#        plt.suptitle(day)
#        ax = plt.subplot2grid((2,1), (0, 0))
#        plt.plot(Balloon.index.to_pydatetime(), Balloon.p, label='Balloon, original')
#        #plt.plot(Pressure.index.to_pydatetime(), Pressure['Pressure [hPa]'], label='Mast')
#        #plt.plot(Pressure.index.to_pydatetime(), func(Pressure.time, *popt), '--', label='', color='black')       
#        plt.plot(Balloon.index.to_pydatetime(), p, label='Balloon, corrected')
#        plt.legend()
#        plt.grid(True)
#        ax.xaxis.set_major_locator(mdates.MinuteLocator(byminute=[0,30,60]))
#        ax.xaxis.set_major_formatter( mdates.DateFormatter('%H:%M'))
#        plt.ylabel('near-surface pressure (hPa)')
#        plt.ylim(p0-2, p0+2)
#        ax = plt.subplot2grid((2,1), (1, 0))
#        plt.plot(Balloon.h_WGS84, label='h_GPS')              
#        plt.plot(Balloon.h_pres, label='h_pres, original')      
#        plt.plot(h, label='h_pres, corrected')
#        plt.legend()
#        plt.grid(True)
#        ax.xaxis.set_major_locator(mdates.MinuteLocator(byminute=[0,30,60]))
#        ax.xaxis.set_major_formatter( mdates.DateFormatter('%H:%M'))
#        plt.xlabel('time')
#        plt.ylabel('altitude (m)')
        #fig.savefig('plots_data_processing/Pressure_'+day+'.png', dpi=200) 
        
        
        Balloon.p = p
        Balloon.h_pres=h 
        
        RS = RS[RS.HeightGnd<Balloon.h_pres.max()+20]
 
        
        ### Temperature correction: calibrate Thermocouple to PT100
        
        # spikes (due to droplets?)
        Balloon.loc[(Balloon.index > '2020-07-14 14:31:11.00') & (Balloon.index < '2020-07-14 14:31:20.00'),'T_Thermo'] = np.nan
        Balloon.loc[(Balloon.index > '2020-07-14 14:24:26.00') & (Balloon.index < '2020-07-14 14:24:31.00'),'T_PT100'] = np.nan

        # correct PT100 for tau
        tau_PT = 10
        window_slow_signal = round_up_to_odd(2*tau_PT * fs_Balloon) 
        Balloon['slow_PT100'] = sp.signal.savgol_filter(Balloon.T_PT100, window_slow_signal ,2)
        Balloon['PT100_tau'] = Balloon.T_PT100 + np.gradient(Balloon.slow_PT100, 1/fs_Balloon, edge_order =1) * tau_PT 
        # correct thermocouple for tau
        tau_Th = 0.64
        window_slow_signal = round_up_to_odd(2*tau_Th * fs_Balloon) 
        Balloon['slow_Th'] = sp.signal.savgol_filter(Balloon.T_Thermo, window_slow_signal ,2)
        Balloon['Thermo_tau'] = Balloon.T_Thermo + np.gradient(Balloon.slow_Th, 1/fs_Balloon, edge_order =1) * tau_Th
        # Fit thermocouple to PT100 slow signal 
        fit = Balloon[['Thermo_tau','PT100_tau']].dropna()
        fit_Thermo = np.polyfit(fit.Thermo_tau, fit.PT100_tau,1)            
        Balloon['Thermo_corr'] = np.polyval(fit_Thermo, Balloon.Thermo_tau)           
        
        
        ## Tv correction
        # compare Tv to calculated Tv
        Balloon['Tv_from_T'] = Tv(Balloon.RH, Balloon.T_PT100+273.15, Balloon.p*100)
        # fit Tv from USA to Tv from PT100 (tau-corrected) and RH (from LinP)
        def func(x, a,b):
            return x + b            
        fit_data = Balloon[['Tv','Tv_from_T']].dropna()            
        popt, pcov = curve_fit(func, fit_data.Tv, fit_data.Tv_from_T)
        # new Sonic-Tv
        Balloon['Tv_corr'] = func(Balloon.Tv, *popt)  
        
        
        # plot
#        fig = plt.figure(figsize=(15,7))
#        plt.suptitle(day[:10]) 
#        ax = plt.subplot2grid((1,1), (0, 0))
#        ax.plot(Balloon.T_Thermo, label='Thermo orig.', color='C0', alpha=0.5)  
#        ax.plot(Balloon.T_PT100, label='PT100 orig.', color='C1', alpha=0.5)  
#        ax.plot(Balloon.Tv, label='Tv orig.', color='C2', alpha=0.5)     
#        ax.plot(Balloon.Tv_corr, label='Tv orig.', color='C2')  
#        ax.plot(Balloon.Thermo_corr, label='Thermo corr.', color='C0')  
#        ax.plot(Balloon.PT100_tau, label='PT100 corr.', color='C1')  
#        plt.xlabel(u'Time') 
#        plt.ylabel(u'$T$ (\u00B0C)')
#        plt.grid(True)
#        plt.legend()
#        fig.savefig('plots_data_processing/Temperature_time_series'+day+'.png') 
#        
#        fig = plt.figure(figsize=(10,10))
#        plt.suptitle(day[:10]) 
#        ax = plt.subplot2grid((1,1), (0, 0))
#        ax.plot(Balloon.T_Thermo, Balloon.h_pres, label='Thermo orig.', color='C0', alpha=0.5)  
#        ax.plot(Balloon.T_PT100, Balloon.h_pres, label='PT100 orig.', color='C1', alpha=0.5)  
#        ax.plot(Balloon.Tv, Balloon.h_pres, label='Tv orig.', color='C2', alpha=0.5)  
#        ax.plot(Balloon.Tv_corr, Balloon.h_pres, label='Tv corr.', color='C2')  
#        ax.plot(Balloon.Thermo_corr, Balloon.h_pres, label='Thermo corr.', color='C0')  
#        ax.plot(Balloon.PT100_tau, Balloon.h_pres, label='PT100 corr.', color='C1')  
#        ax.plot(RS.Temp, RS.HeightGnd, color='black', label = 'RS {}h'.format(RStime))
#        plt.xlabel(u'$T$ (\u00B0C)') 
#        plt.ylabel('$z_b$ (m)')
#        plt.grid(True)
#        plt.legend()
#        fig.savefig('plots_data_processing/Temperature_profile'+day+'.png') 
#        
#        fig = plt.figure()
#        plt.suptitle(day[:10]) 
#        plt.plot(Balloon.Thermo_corr, Balloon.PT100_tau,'.', ms=0.1)
#        plt.plot(Balloon.Thermo_corr, Balloon.Tv_corr,'.', ms=0.1)
#        plt.legend(markerscale=100)
#        plt.xlabel(u'$T$ (\u00B0C) Thermocouple (corr)') 
#        plt.ylabel(u'$T$ (\u00B0C)') 
#        plt.grid(True)
#        fig.savefig('plots_data_processing/Temperature_relation'+day+'.png') 
        
        if day == '2020-07-24': # Thermocouple seems to run away
            Balloon.Thermo_corr = np.nan


     
        ## drop and rename columns
        Balloon.drop(['Tv', 'T_PT100', 'T_Thermo', 'slow_PT100',  'Tv_from_T','slow_Th', 'Thermo_tau'], axis=1, inplace=True)
        Balloon = Balloon.rename(columns={
            'PT100_tau': 'T_PT100',
            'Thermo_corr': 'T_Thermo',
            'Tv_corr': 'Tv'
            })
       
    
        ### Wind direction: average and rad to deg
        
        Balloon['wind_dir'] = np.nan
        u = Balloon.u_E.rolling(int(fs_Balloon), center=True, min_periods=0).median()
        v = Balloon.v_E.rolling(int(fs_Balloon), center=True, min_periods=0).median()
        
        Balloon.wind_dir = Balloon.wind_dir.where(((v>0) & (u>0))==False, np.arctan(v/u))
        Balloon.wind_dir = Balloon.wind_dir.where(((v>0) & (u<=0))==False, np.arctan(-u/v) + 0.5*np.pi)
        Balloon.wind_dir = Balloon.wind_dir.where(((v<=0) & (u>0))==False, np.arctan(-u/v) - 0.5*np.pi)
        Balloon.wind_dir = Balloon.wind_dir.where(((v<=0) & (u<=0))==False, np.arctan(v/u) - np.pi)       
        
        Balloon.wind_dir = np.degrees(Balloon.wind_dir)   
        Balloon.wind_dir = Balloon.wind_dir + 180.
        #Balloon.wind_dir = Balloon.wind_dir.where(Balloon.wind_dir>0, Balloon.wind_dir+360)    
    
#        fig = plt.figure(figsize=(15,7))
#        plt.suptitle(day[:10])   
#        plt.plot(Balloon.uv_E*10, color='grey', label = 'wind speed *10') 
#        plt.plot(np.degrees(Balloon.yaw),'.',ms=2, label = 'yaw')  
#        plt.plot(np.degrees(Balloon.roll))  
#        plt.plot(Balloon.h_pres/10)
#        plt.plot(Balloon.wind_dir,'.') 
#        plt.legend()
#        plt.ylabel(u'wind dir (\u00B0)') 
#        plt.xlabel('time')
#        plt.grid(True)
#        fig.savefig('plots_data_processing/Wind_dir'+day+'.png') 

        ### corrections for particular days:           

        if day == '2020-07-13': 
            Balloon = Balloon['{} 11:53:29.00'.format(day[:10]):'{} 13:26:50.00'.format(day[:10])].append(Balloon['{} 13:33:56.00'.format(day[:10]):])
            Balloon['{} 13:55:42.00'.format(day[:10]) : '{} 13:56:07.00'.format(day[:10])].wind_dir = np.nan



    
        ### check data
            
        # Print columns with NaNs
        print 'Number of lines with NaN: {}' .format(  len(Balloon[Balloon.isnull().any(axis=1)]))
        
        Balloon.drop(['Acc_x', 'Acc_y', 'Acc_z', 'Omg_x', 'Omg_y', 'Omg_z', 'u_EI', 'v_EI', 'w_EI'], axis=1, inplace=True)
        
        Balloon = Balloon.rename(columns={
                'h_WGS84': 'h_gps'
                })
        
    
        ### round values
        for column in [  u'u_USA', u'v_USA', u'w_USA', u'u_E', 
                       u'v_E', u'w_E', u'uv_E', u'longitudinalwind', u'lateralwind', u'T_PT100', u'T_Thermo', u'Tv']:
            Balloon[column] = Balloon[column].round(4)
            
        for column in [u'roll', u'pitch', u'yaw', u'h_pres', u'h_gps', u'RH',  u'wind_dir', u'p']:
            Balloon[column] = Balloon[column].round(3) 
            
        for column in [ u'Lon', u'Lat']:
            Balloon[column] = Balloon[column].round(7) 
            
        Balloon.index = Balloon.index.round('10ms')
        
        
        
        
        #%%  Plot data
    

        
#        fig = plt.figure(figsize = (13,8))
#        plt.plot(Balloon.h_pres/100)
#        plt.plot(Balloon['u_E'])
#        plt.plot(Balloon['v_E']) 
#        plt.plot(Balloon.w_E)
#        plt.suptitle('Sonic wind speeds {}'.format(day), fontsize=14)
#        plt.ylabel('wind speed (m/s)', fontsize='large')
#        plt.xlabel('Time', fontsize='large')
#        plt.grid(True)
#        plt.legend(loc='best')
#        fig.savefig('plots_data_processing/Wind_speed'+day+'.png') 

    
#        fig = plt.figure(figsize=(15,7))
#        plt.suptitle(day[:10]) 
#        # Temp
#        ax = plt.subplot2grid((1,2), (0, 0))
#        ax.plot(Balloon.T_Thermo, label='Thermo')  
#        ax.plot(Balloon.T_PT100, label='PT100')  
#        ax.plot(Balloon.Tv, label='Tv') 
#        plt.xlabel(u'$T$ (\u00B0C)') 
#        plt.ylabel('$z_b$ (km)')
#        plt.grid(True)
#        plt.legend()
#        # RH
#        ax = plt.subplot2grid((1,2), (0, 1)) 
#        plt.grid(True) 
#        plt.plot(Balloon.RH, label = 'LinP')
#        plt.xlabel('$RH$ (proz)')   
#        plt.legend()

        
        plot = 1  
        if plot == 1:
            
#            
#            # Plot altitudes
#            fig = plt.figure(figsize = (12,8))
#            plt.suptitle(day)
#            ax0 = fig.add_subplot(211)
#            ax0.plot(Balloon.index.to_pydatetime(), Balloon['h_pres'], label='pressure')
#            ax0.plot(Balloon.index.to_pydatetime(), Balloon['h_gps'], label='GPS')
#            ax0.set_title('Altitude Time series')
#            plt.legend()
#            plt.grid(True)
#            ax1 = fig.add_subplot(212)
#            ax1.hist(Balloon['h_pres'].dropna(), bins = 100, alpha=0.5)
#            ax1.hist(Balloon['h_gps'].dropna(), bins = 100, alpha=0.5)
#            #ax1.set_title('Histogram')
#            plt.legend()
#            plt.grid(True)
#            fig.savefig('../Data/Quicklooks/lev1/Sonic_Time_series_lev1_'+day+'.png', dpi=300)
                  
            
            
            ascentcolor = 'C0'
            descentcolor = 'C1'
            plt.rcParams.update({'font.size': 13})
            
            fig = plt.figure(figsize = (12,8))
            fig.suptitle('Sonic vertical profiles, ' + day)
            h_plot = 'h_pres' 
            maxalt = Balloon.index[Balloon[h_plot] == Balloon[h_plot].max()][0]  
            ascent = Balloon[ : maxalt]
            descent = Balloon[maxalt : ]
            
            ax0 = plt.subplot2grid((1,4), (0, 1), colspan=1)
            ax0.set_ylim(-20, Balloon[h_plot].max()+50)
            plt.xlabel('Wind speed (m/s)')
            ax0.plot(ascent.uv_E,ascent[h_plot],'-',label='ascent', color = ascentcolor)
            ax0.plot(descent.uv_E,descent[h_plot],'-',label='descent', color = descentcolor)
            ax0.plot(RS.Speed, RS.HeightGnd, color='black', label = 'RS {}h'.format(RStime))
            ax0.set_yticklabels([])
            
            ax3 = plt.subplot2grid((1,4), (0, 2), colspan=1)
            ax3.set_ylim(-20, Balloon[h_plot].max()+50)
            ax3.set_xlabel(u'Wind direction (\u00B0)')
            ax3.plot(ascent.wind_dir,ascent[h_plot],'.', ms=2, label='ascent', color = ascentcolor)
            ax3.plot(descent.wind_dir,descent[h_plot],'.', ms=2,label='descent', color = descentcolor)
            ax3.plot(RS.Dir, RS.HeightGnd,'.', ms=3, color='black', label = 'RS {}h'.format(RStime))
            ax3.set_yticklabels([])
            
            ax1 = plt.subplot2grid((1,4), (0, 0))
            ax1.set_ylim(-20, Balloon[h_plot].max()+50)
            ax1.plot(ascent['T_PT100'], ascent[h_plot],'-',label='', color = ascentcolor)            
            ax1.plot(descent['T_PT100'], descent[h_plot],'-',label='', color = descentcolor)
            ax1.plot(ascent['T_Thermo'], ascent[h_plot],'--',label='', color = ascentcolor, alpha=0.5)            
            ax1.plot(descent['T_Thermo'], descent[h_plot],'--',label='', color = descentcolor, alpha=0.5)
    #        ax1.plot(ascent['Tv'], ascent[h_plot],'-',label='', color = ascentcolor)            
    #        ax1.plot(descent['Tv'], descent[h_plot],'-',label='', color = descentcolor)
            ax1.plot(np.nan,'-',label='PT100', color = 'grey')            
            ax1.plot(np.nan,'-',label='Thermo', color = 'grey', alpha=0.5)             
            ax1.plot(RS.Temp, RS.HeightGnd, color='black', label = ''.format(RStime))
            ax1.legend(loc=2)
            ax1.set_xlabel(u'Temperature (\u00B0C)')
            plt.ylabel('pressure altitude (m)')

            
            ax2 = plt.subplot2grid((1,4), (0, 3))
            ax2.set_ylim(-20, Balloon[h_plot].max()+50)
            ax2.plot(descent['RH'], descent[h_plot],'-', label='descent', color = descentcolor)
            ax2.plot(ascent['RH'], ascent[h_plot],'-', label='ascent', color = ascentcolor)
            ax2.plot(RS.RH, RS.HeightGnd, color='black', label = 'RS {}h'.format(RStime))
            ax2.set_xlabel('RH (%)')
            ax2.set_yticklabels([])
            ax2.legend(loc=1)        
                       
            for ax in [ax0, ax1, ax2, ax3]:
                ax.xaxis.set_major_formatter(FormatStrFormatter('%g')) 
                ax.grid(True)
            plt.tight_layout()
            plt.subplots_adjust(top=0.94)
                
            
            fig.savefig('../Data/Quicklooks/lev1/Sonic_VertProfile_lev1_'+day+'.png', dpi=300)
            print 'Quicklook saved'
               
        

    
    
        #%% Save to file
        
        #plt.close('all')
        Save_as = '../Data/Data_postprocessed/lev1/' + '/Balloon_Sonic_postprocessed_lev_1' + "_" + day[:10] + "_from_" +  Balloon.index[0].strftime('%H:%M').replace(':', '-') + "_" + 'to' + "_" + Balloon.index[-1].strftime('%H:%M').replace(':', '-') + '.txt'
        #Balloon.to_csv(Save_as,header=True,index=True,sep=",",na_rep=" ")
        
        
        
        
        
        
        
        
        
    
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
